==> sp-pkg_1.1.0.orig.tar.gz: sp_pkg-1.1.0/unit_tests/test_scan_rpm.py <==
# SPDX-FileCopyrightText: StorPool <support@storpool.com>
# SPDX-License-Identifier: BSD-2-Clause
"""Test the Repo class."""

from __future__ import annotations

import pathlib
import tempfile
import typing

import pytest

from sp_pkg.scan import rpm as s_rpm
from sp_pkg.scan import yum as s_yum

from . import test_utils as tutil


if typing.TYPE_CHECKING:
    from typing import Final


@pytest.fixture
def built_cfg() -> tutil.BuiltRPMConfig:
    """Set up the environment and stuff."""
    cfg, sp_hello = tutil.get_config()
    return tutil.BuiltRPMConfig(
        t_cfg=cfg, t_built=s_rpm.scan_built(cfg, pathlib.Path(sp_hello)) if sp_hello else None
    )


@pytest.mark.parametrize("path", ["/nonexistent", ".", "/bin"])
def test_bad_dir(path: str) -> None:
    """Make sure parsing a non-repo directory fails."""
    with pytest.raises(s_rpm.RepoError):
        s_yum.Repo(pathlib.Path(path).absolute())


def test_empty_repo(built_cfg: tutil.BuiltRPMConfig) -> None:
    """Parse an empty repository."""
    with tempfile.TemporaryDirectory() as tempd_name:
        tempd: Final = pathlib.Path(tempd_name)
        print(f"\nUsing tempdir {tempd}")

        repodir: Final = tempd / "repo"
        tutil.create_empty_repo(built_cfg.t_cfg, repodir)

        print("- now create a Repo instance")
        repo: Final = s_yum.Repo(repodir)
        print(f"- whee, got {repo}")

        print("- making sure there are no source packages")
        assert repo.sources.repomd.primary.packages == {}
        assert repo.sources.repomd.filelists.packages == {}
        assert repo.sources.repomd.other.packages == {}

        print("- making sure there are no binary packages")
        assert repo.arches["x86_64"].repomd.primary.packages == {}
        assert repo.arches["x86_64"].repomd.filelists.packages == {}
        assert repo.arches["x86_64"].repomd.other.packages == {}

        if built_cfg.t_built is None:
            print("- skipping the add-a-package checks")
            return

        print("- copying the source package in")
        built_cfg.t_cfg.check_call(
            [
                "cp",
                "--",
                built_cfg.t_built.source.path,
                repodir / "SRPMS/Sources/",
            ]
        )
        print(f"- copying {len(built_cfg.t_built.binaries)} binary packages in")
        for rpmf in built_cfg.t_built.binaries:
            built_cfg.t_cfg.check_call(["cp", "--", rpmf.path, repodir / "x86_64/Packages/"])

        before: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        print("- running createrepo_c on the sources repo")
        built_cfg.t_cfg.check_call(["createrepo_c", "--", repodir / "SRPMS"])
        midd: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        assert midd != before

        print("- running createrepo_c on the arch repo")
        built_cfg.t_cfg.check_call(["createrepo_c", "--", repodir / "x86_64"])
        after: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        assert after != midd
        assert after != before

        print("- now creating another Repo instance")
        repo_final: Final = s_yum.Repo(repodir)
        print(f"- whee, got {repo_final}")

        assert sorted(repo_final.sources.repomd.primary.packages) == [built_cfg.t_built.source.name]
        assert sorted(repo_final.sources.repomd.filelists.packages) == [
            built_cfg.t_built.source.name
        ]
        assert sorted(repo_final.sources.repomd.other.packages) == [built_cfg.t_built.source.name]

        pkglist: Final = sorted(rpmf.name for rpmf in built_cfg.t_built.binaries)
        assert sorted(repo_final.arches["x86_64"].repomd.primary.packages) == pkglist
        assert sorted(repo_final.arches["x86_64"].repomd.filelists.packages) == pkglist
        assert sorted(repo_final.arches["x86_64"].repomd.other.packages) == pkglist

==> sp-pkg_1.2.0.orig.tar.gz: sp_pkg-1.2.0/unit_tests/test_scan_rpm.py <==
# SPDX-FileCopyrightText: StorPool <support@storpool.com>
# SPDX-License-Identifier: BSD-2-Clause
"""Test the Repo class."""

from __future__ import annotations

import pathlib
import tempfile
import typing

import pytest

from sp_pkg.scan import rpm as s_rpm
from sp_pkg.scan import yum as s_yum

from . import test_utils as tutil


if typing.TYPE_CHECKING:
    from typing import Final


@pytest.fixture
def built_cfg() -> tutil.BuiltRPMConfig:
    """Set up the environment and stuff."""
    cfg, sp_hello = tutil.get_config()
    return tutil.BuiltRPMConfig(
        t_cfg=cfg,
        t_built=s_rpm.scan_built(cfg, pathlib.Path(sp_hello)) if sp_hello else None,
    )


@pytest.mark.parametrize("path", ["/nonexistent", ".", "/bin"])
def test_bad_dir(path: str) -> None:
    """Make sure parsing a non-repo directory fails."""
    with pytest.raises(s_rpm.RepoError):
        s_yum.Repo(pathlib.Path(path).absolute())


def test_empty_repo(built_cfg: tutil.BuiltRPMConfig) -> None:
    """Parse an empty repository."""
    with tempfile.TemporaryDirectory() as tempd_name:
        tempd: Final = pathlib.Path(tempd_name)
        print(f"\nUsing tempdir {tempd}")

        repodir: Final = tempd / "repo"
        tutil.create_empty_repo(built_cfg.t_cfg, repodir)

        print("- now create a Repo instance")
        repo: Final = s_yum.Repo(repodir)
        print(f"- whee, got {repo}")

        print("- making sure there are no source packages")
        assert repo.sources.repomd.primary.packages == {}
        assert repo.sources.repomd.filelists.packages == {}
        assert repo.sources.repomd.other.packages == {}

        print("- making sure there are no binary packages")
        assert repo.arches["x86_64"].repomd.primary.packages == {}
        assert repo.arches["x86_64"].repomd.filelists.packages == {}
        assert repo.arches["x86_64"].repomd.other.packages == {}

        if built_cfg.t_built is None:
            print("- skipping the add-a-package checks")
            return

        print("- copying the source package in")
        built_cfg.t_cfg.check_call(
            [
                "cp",
                "--",
                built_cfg.t_built.source.path,
                repodir / "SRPMS/Sources/",
            ],
        )
        print(f"- copying {len(built_cfg.t_built.binaries)} binary packages in")
        for rpmf in built_cfg.t_built.binaries:
            built_cfg.t_cfg.check_call(["cp", "--", rpmf.path, repodir / "x86_64/Packages/"])

        before: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        print("- running createrepo_c on the sources repo")
        built_cfg.t_cfg.check_call(["createrepo_c", "--", repodir / "SRPMS"])
        midd: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        assert midd != before

        print("- running createrepo_c on the arch repo")
        built_cfg.t_cfg.check_call(["createrepo_c", "--", repodir / "x86_64"])
        after: Final = sorted(path for path in repodir.rglob("*") if path.is_file())
        assert after != midd
        assert after != before

        print("- now creating another Repo instance")
        repo_final: Final = s_yum.Repo(repodir)
        print(f"- whee, got {repo_final}")

        assert sorted(repo_final.sources.repomd.primary.packages) == [built_cfg.t_built.source.name]
        assert sorted(repo_final.sources.repomd.filelists.packages) == [
            built_cfg.t_built.source.name,
        ]
        assert sorted(repo_final.sources.repomd.other.packages) == [built_cfg.t_built.source.name]

        pkglist: Final = sorted(rpmf.name for rpmf in built_cfg.t_built.binaries)
        assert sorted(repo_final.arches["x86_64"].repomd.primary.packages) == pkglist
        assert sorted(repo_final.arches["x86_64"].repomd.filelists.packages) == pkglist
        assert sorted(repo_final.arches["x86_64"].repomd.other.packages) == pkglist
